/* SAMHAIN file system integrity testing                                   */
/* Copyright (C) 1999 Rainer Wichmann                                      */
/*                                                                         */
/*  This program is free software; you can redistribute it                 */
/*  and/or modify                                                          */
/*  it under the terms of the GNU General Public License as                */
/*  published by                                                           */
/*  the Free Software Foundation; either version 2 of the License, or      */
/*  (at your option) any later version.                                    */
/*                                                                         */
/*  This program is distributed in the hope that it will be useful,        */
/*  but WITHOUT ANY WARRANTY; without even the implied warranty of         */
/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          */
/*  GNU General Public License for more details.                           */
/*                                                                         */
/*  You should have received a copy of the GNU General Public License      */
/*  along with this program; if not, write to the Free Software            */
/*  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              */

#ifndef SAMHAIN_H
#define SAMHAIN_H


#define _(string)  string
#define N_(string) string


#undef  SH_BUFSIZE
#define SH_BUFSIZE     1024

#define SH_MINIBUF     64
#define SH_MAXBUF      4096

#define OWNER_MAX 20
#define GROUP_MAX 20
#define KEY_MAX   50
#define KEY_LEN   50
#define PRIV_MAX  1024    /* buffer for privileged content */

#undef  GOOD
#define GOOD           1

#undef  BAD
#define BAD            0


enum {
  SH_LEVEL_READONLY    = 1, 
  SH_LEVEL_LOGFILES    = 2,
  SH_LEVEL_LOGGROW     = 3,
  SH_LEVEL_NOIGNORE    = 4,
  SH_LEVEL_ALLIGNORE   = 5
};

enum {
  SH_CHECK_NONE    = 0, 
  SH_CHECK_INIT    = 1,
  SH_CHECK_CHECK   = 2
};

typedef struct {
  unsigned long  alarm_interval;
  unsigned long  alarm_last;
} sh_timer_t;

typedef struct {
  char   user[SH_MINIBUF+1];       /* who runs the process            */ 
  char   real_user[SH_MINIBUF+1];  /* and what is her real name       */
  char   home[SH_BUFSIZE+1];       /* and home directory              */

  char   localhost[SH_MINIBUF+1];  /* local hostname                  */
  char   timeserver[256+1];        /* timeserver addres               */
  char   address[256+1];           /* mail address                    */

  char   filedata_hash[50+1];
  int    checkSum;                 /* whether to init/check checksums */
  int    openfiles;                /* number of open files            */

  int    opts;                     /* reading cl options              */
  int    looptime;                 /* timing for main loop            */
  int    modus;                    /* deamon or not                   */
  int    locked;                   /* BAD if logfile not locked       */

  sh_timer_t mailNum;
  sh_timer_t mailTime;
  sh_timer_t fileCheck;

  unsigned long start_time;
} sh_struct;

typedef struct {
  char   sigkey_old[KEY_LEN+1];
  char   sigkey_new[KEY_LEN+1];
  char   mailkey_old[KEY_MAX+1];
  char   mailkey_new[KEY_MAX+1];
  char   crypt[KEY_MAX+1]; 
  char   vernam[KEY_MAX+1]; 
  int    mlock_failed;
} sh_key_t;

extern sh_struct sh; 
extern sh_key_t  *skey; 


#include "sh_mem.h"

#endif









