/* SAMHAIN file system integrity testing                                   */
/* Copyright (C) 1999 Rainer Wichmann                                      */
/*                                                                         */
/*  This program is free software; you can redistribute it                 */
/*  and/or modify                                                          */
/*  it under the terms of the GNU General Public License as                */
/*  published by                                                           */
/*  the Free Software Foundation; either version 2 of the License, or      */
/*  (at your option) any later version.                                    */
/*                                                                         */
/*  This program is distributed in the hope that it will be useful,        */
/*  but WITHOUT ANY WARRANTY; without even the implied warranty of         */
/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          */
/*  GNU General Public License for more details.                           */
/*                                                                         */
/*  You should have received a copy of the GNU General Public License      */
/*  along with this program; if not, write to the Free Software            */
/*  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              */


#ifndef SH_UTILS_H
#define SH_UTILS_H

#include <stdarg.h>
#include "sh_error.h"
#include "sh_unix.h"


/* OpenBSD-like strlcpy, strlcat functions (not the original ones - don't know
 * about possible copyright issue)
 */
#ifndef HAVE_STRLCAT
size_t strlcat(char * dst, const char *src, size_t siz);
#endif
#ifndef HAVE_STRLCPY
size_t strlcpy(char * dst, const char *src, size_t siz);
#endif

/* a simple compressor
 */
long sh_util_compress (char * dest, char * src, unsigned long dest_size);

/* an even simpler en-/decoder 
 */
void sh_util_encode (char * data, char * salt, int mode);

/* set timer for main loop
 */
int sh_util_setlooptime (char * str);

/* whether init or check the database
 */
int  sh_util_setchecksum (char * str);

/* compare an in_string against a regular expression regex_str
   return GOOD on successful match
int sh_util_checkmatch (char * in_str, char * regex_str);
 */

/* check if string is numeric only
 */
int sh_util_isnum (char *str);

/* init a key w/random string
 */
int sh_util_keyinit (char * buf, long size);


/* returns freshly allocated memory, return value should be free'd
 */
char * sh_util_filename(char * fullpath);

/* returns freshly allocated memory, return value should be free'd
 */
char * sh_util_safe_name (char * name);

/* check max size of printf result string
 */
int sh_util_printf_maxlength (const char * fmt, va_list  vl);

/* check for obscure filenames
 */
int sh_util_obscurename (ShErrLevel level, char * name);

/* returns freshly allocated memory, return value should be free'd
 */
char * sh_util_basename(char * fullpath);

#endif
